changeset 15897:4e44a9eaceec

Go back to using ~/.gaim/ until we decide what to do.
author Mark Doliner <mark@kingant.net>
date Sat, 24 Mar 2007 23:28:25 +0000
parents fd6e3382e734
children 9cfe41743c65
files libpurple/util.c
diffstat 1 files changed, 3 insertions(+), 3 deletions(-) [+]
line wrap: on
line diff
--- a/libpurple/util.c	Sat Mar 24 23:11:15 2007 +0000
+++ b/libpurple/util.c	Sat Mar 24 23:28:25 2007 +0000
@@ -2184,8 +2184,8 @@
 #endif
 }
 
 /* returns a string of the form ~/.purple, where ~ is replaced by the user's home
  * dir. Note that there is no trailing slash after .purple. */
 const char *
 purple_user_dir(void)
 {
@@ -2196,7 +2196,7 @@
 
 		if (hd) {
 			g_strlcpy((char*) &home_dir, hd, sizeof(home_dir));
-			g_strlcat((char*) &home_dir, G_DIR_SEPARATOR_S ".purple",
+			g_strlcat((char*) &home_dir, G_DIR_SEPARATOR_S ".gaim",
 					sizeof(home_dir));
 		}
 	}
@@ -2184,8 +2184,8 @@
 }
 
-/* returns a string of the form ~/.purple, where ~ is replaced by the user's home
- * dir. Note that there is no trailing slash after .purple. */
+/* returns a string of the form ~/.gaim, where ~ is replaced by the user's home
+ * dir. Note that there is no trailing slash after .gaim. */
 const char *
 purple_user_dir(void)